<?php
/**
 * Welcome
 */
class resilient_screen {

	public function __construct() {

		add_action( 'admin_menu', array( $this, 'resilient_register_menu' ) );
		add_action( 'load-themes.php', array( $this, 'resilient_activation_admin_notice' ) );
		add_action( 'admin_enqueue_scripts', array( $this, 'resilient_style_and_scripts' ) );
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'resilient_scripts_for_customizer' ) );
        
		/* Welcome Screen Builder */
		
		add_action( 'resilient_info_screen', array( $this, 'resilient_getting_started' ), 	    10 );
		add_action( 'resilient_info_screen', array( $this, 'resilient_action_required' ), 	    20 );
		add_action( 'resilient_info_screen', array( $this, 'resilient_github' ), 		            40 );
		add_action( 'wp_ajax_resilient_dismiss_required_action', array( $this, 'resilient_dismiss_required_action_callback') );
		add_action( 'wp_ajax_nopriv_resilient_dismiss_required_action', array($this, 'resilient_dismiss_required_action_callback') );

	}

	public function resilient_register_menu() {
		add_theme_page( 'Theme About', 'Theme About', 'activate_plugins', 'resilient-info', array( $this, 'resilient_welcome_screen' ) );
	}

	public function resilient_activation_admin_notice() {
		global $pagenow;

		if ( is_admin() && ('themes.php' == $pagenow) && isset( $_GET['activated'] ) ) {
			add_action( 'admin_notices', array( $this, 'resilient_admin_notice' ), 99 );
		}
	}

	/**
	 * @sfunctionse 1.8.2.4
	 */
	public function resilient_admin_notice() {
		?>
			<div class="updated notice is-dismissible">
				<p><?php echo sprintf( esc_html__( 'Welcome! Thank you for choosing the resilient multipurpose wp theme! Start by examining usage to fully utilize the best advantage your theme offers', 'resilient' ), '<a href="' . esc_url( admin_url( 'themes.php?page=resilient-info' ) ) . '">', '</a>' ); ?></p>
				<p><a href="<?php echo esc_url( admin_url( 'themes.php?page=resilient-info' ) ); ?>" class="button" style="text-decoration: none;"><?php _e( 'Start using the resilient theme', 'resilient' ); ?></a></p>
			</div>
		<?php
	}

	/**
	 * @sfunctionse  1.8.2.4
	 */
	public function resilient_style_and_scripts( $hook_suffix ) {

		if ( 'appearance_page_resilient-info' == $hook_suffix ) {
			
			wp_enqueue_style( 'resilient-info-css', get_template_directory_uri() . '/inc/welcome/css/bootstrap.css' );
			wp_enqueue_style( 'resilient-info-screen-css', get_template_directory_uri() . '/inc/welcome/css/welcome.css' );
			wp_enqueue_script( 'resilient-info-screen-js', get_template_directory_uri() . '/inc/welcome/js/welcome.js', array('jquery') );

			global $resilient_required_actions;

			$nr_actions_required = 0;

			if( get_option('resilient_show_required_actions') ):
				$resilient_show_required_actions = get_option('resilient_show_required_actions');
			else:
				$resilient_show_required_actions = array();
			endif;

			if( !empty($resilient_required_actions) ):
				foreach( $resilient_required_actions as $resilient_required_action_value ):
					if(( !isset( $resilient_required_action_value['check'] ) || ( isset( $resilient_required_action_value['check'] ) && ( $resilient_required_action_value['check'] == false ) ) ) && ((isset($resilient_show_required_actions[$resilient_required_action_value['id']]) && ($resilient_show_required_actions[$resilient_required_action_value['id']] == true)) || !isset($resilient_show_required_actions[$resilient_required_action_value['id']]) )) :
						$nr_actions_required++;
					endif;
				endforeach;
			endif;

			wp_localize_script( 'resilient-info-screen-js', 'resilientLiteWelcomeScreenObject', array(
				'nr_actions_required' => $nr_actions_required,
				'ajaxurl' => admin_url( 'admin-ajax.php' ),
				'template_directory' => get_template_directory_uri(),
				'no_required_actions_text' => __( 'No action is required for you right now.','resilient' )
			) );
		}
	}

	/**
	 * @sfunctionse  1.8.2.4
	 */
	public function resilient_scripts_for_customizer() {

		wp_enqueue_style( 'resilient-info-screen-customizer-css', get_template_directory_uri() . '/inc/resilient-info/css/welcome_customizer.css' );
		wp_enqueue_script( 'resilient-info-screen-customizer-js', get_template_directory_uri() . '/inc/resilient-info/js/welcome_customizer.js', array('jquery'), '20120206', true );

		global $resilient_required_actions;

		$nr_actions_required = 0;

		if( get_option('resilient_show_required_actions') ):
			$resilient_show_required_actions = get_option('resilient_show_required_actions');
		else:
			$resilient_show_required_actions = array();
		endif;

		if( !empty($resilient_required_actions) ):
			foreach( $resilient_required_actions as $resilient_required_action_value ):
				if(( !isset( $resilient_required_action_value['check'] ) || ( isset( $resilient_required_action_value['check'] ) && ( $resilient_required_action_value['check'] == false ) ) ) && ((isset($resilient_show_required_actions[$resilient_required_action_value['id']]) && ($resilient_show_required_actions[$resilient_required_action_value['id']] == true)) || !isset($resilient_show_required_actions[$resilient_required_action_value['id']]) )) :
					$nr_actions_required++;
				endif;
			endforeach;
		endif;

		wp_localize_script( 'resilient-info-screen-customizer-js', 'resilientLiteWelcomeScreenObject', array(
			'nr_actions_required' => $nr_actions_required,
			'aboutpage' => esc_url( admin_url( 'themes.php?page=resilient-info#actions_required' ) ),
			'customizerpage' => esc_url( admin_url( 'customize.php#actions_required' ) ),
			'themeinfo' => __('View Theme Info','resilient'),
		) );
	}

	/**
	 * @sfunctionse 1.8.2.4
	 */
	public function resilient_dismiss_required_action_callback() {

		global $resilient_required_actions;
		$resilient_dismiss_id = (isset($_GET['dismiss_id'])) ? $_GET['dismiss_id'] : 0;
		echo $resilient_dismiss_id; 
		if( !empty($resilient_dismiss_id) ):

			if( get_option('resilient_show_required_actions') ):
				$resilient_show_required_actions = get_option('resilient_show_required_actions');
				$resilient_show_required_actions[$resilient_dismiss_id] = false;
				update_option( 'resilient_show_required_actions',$resilient_show_required_actions );


			else:

				$resilient_show_required_actions_new = array();
				if( !empty($resilient_required_actions) ):
					foreach( $resilient_required_actions as $resilient_required_action ):
						if( $resilient_required_action['id'] == $resilient_dismiss_id ):
							$resilient_show_required_actions_new[$resilient_required_action['id']] = false;
						else:
							$resilient_show_required_actions_new[$resilient_required_action['id']] = true;
						endif;
					endforeach;
				update_option( 'resilient_show_required_actions', $resilient_show_required_actions_new );
				endif;
			endif;
		endif;
		die(); 
	}

	/**
	 * @sfunctionse 1.8.2.4
	 */
	public function resilient_welcome_screen() {

		get_template_part( ABSPATH . 'wp-load.php' );
		get_template_part( ABSPATH . 'wp-admin/admin.php' );
		get_template_part( ABSPATH . 'wp-admin/admin-header.php' );
		
		
		?>
		<div class="container-fluid">
		<div class="row">
		<div class="col-md-12">
		<ul class="resilient-nav-tabs" role="tablist">
			<li role="presentation" class="active"><a href="#getting_started" aria-controls="getting_started" role="tab" data-toggle="tab"><?php esc_html_e( 'Beginning','resilient'); ?></a></li>
			<li role="presentation"><a href="#github" aria-controls="github" role="tab" data-toggle="tab"><?php esc_html_e( 'Descriptions','resilient'); ?></a></li>
			<li role="presentation"><a href="#actions_required" aria-controls="actions_required" role="tab" data-toggle="tab"><?php esc_html_e( 'Other Products','resilient'); ?></a></li>

		
		</ul>
		</div>
		</div>
		</div>

		<div class="resilient-tab-content">
			<?php do_action( 'resilient_info_screen' ); ?>
		</div>
		<?php
	}

	/**
	 *Started
	 *
	 */
	public function resilient_getting_started() {
		require_once ( get_template_directory() . '/inc/welcome/sections/getting-started.php' );
	}
	
	/**
	 * ACtion Required
	 *
	 */
	public function resilient_action_required() {
		require_once( get_template_directory() . '/inc/welcome/sections/other-product.php' );
	}
	
	/**
	 * Github
	 *
	 */
	public function resilient_github() {
		require_once( get_template_directory() . '/inc/welcome/sections/github.php' );
	}

}
$GLOBALS['resilient_screen'] = new resilient_screen();